@@ -6,8 +6,16 @@ compliance_checker/cfutil.py
 from cf_units import Unit
 from pkg_resources import resource_filename
 from collections import defaultdict
+import warnings
+from functools import partial
+import six
 import csv
 import re
+try:
+    from functools import lru_cache
+# Fallback for Python < 3.2
+except ImportError:
+    from functools32 import lru_cache
 
 # For python2/python3 support
 try:
@@ -19,26 +27,26 @@ except NameError:
 _UNITLESS_DB = None
 _SEA_NAMES = None
 
-VALID_LAT_UNITS = [
+VALID_LAT_UNITS = {
     'degrees_north',
     'degree_north',
     'degree_n',
     'degrees_n',
     'degreen',
     'degreesn'
-]
-VALID_LON_UNITS = [
+}
+VALID_LON_UNITS = {
     'degrees_east',
     'degree_east',
     'degree_e',
     'degrees_e',
     'degreee',
     'degreese'
-]
+}
 
 
 # We can't import appendix d without getting circular imports
-DIMENSIONLESS_VERTICAL_COORDINATES = [
+DIMENSIONLESS_VERTICAL_COORDINATES = {
     'ocean_s_coordinate',
     'ocean_s_coordinate_g1',
     'ocean_s_coordinate_g2',
@@ -50,18 +58,75 @@ DIMENSIONLESS_VERTICAL_COORDINATES = [
     'atmosphere_sigma_coordinate',
     'atmosphere_ln_pressure_coordinate',
     'atmosphere_sleve_coordinate'
-]
+}
+
+def attr_membership(attr_val, value_set, attr_type=basestring,
+                          modifier_fn=lambda x: x):
+    """
+    Helper function passed to netCDF4.Dataset.get_attributes_by_value
+    Checks that `attr_val` exists, has the same type as `attr_type`,
+    and is contained in `value_set`
+    attr_val: The value of the attribute being checked
+    attr_type: A type object that the `attr_val` is expected to have the same
+               type as.  If the type is not the same, a warning is issued and
+               the code attempts to cast `attr_val` to the expected type.
+    value_set: The set against which membership for `attr_val` is tested
+    modifier_fn: A function to apply to attr_val prior to applying the set
+                 membership test
+
+    """
+    if attr_val is None:
+        return False
+
+    if not isinstance(attr_val, attr_type):
+        warnings.warn("Attribute is of type {}, {} expected. "
+                      "Attempting to cast to expected type.".format(type(attr_val),
+                                                                    attr_type))
+        try:
+            # if the expected type is basestring, try casting to unicode type
+            # since basestring can't be instantiated
+            if attr_type is basestring:
+                new_attr_val = six.text_type(attr_val)
+            else:
+                new_attr_val = attr_type(attr_val)
+        # catch casting errors
+        except (ValueError, UnicodeEncodeError) as e:
+            warnings.warn("Could not cast to type {}".format(attr_type))
+            return False
+    else:
+        new_attr_val = attr_val
+
+    try:
+        is_in_set = modifier_fn(new_attr_val) in value_set
+    except Exception as e:
+        warnings.warn('Could not apply modifier function {} to value: '
+                      ' {}'.format(modifier_fn, e.msg))
+        return False
+
+    return is_in_set
 
 
-def get_unitless_standard_names(xml_tree, units):
+@lru_cache(128)
+def is_dimensionless_standard_name(xml_tree, standard_name):
     '''
-    Returns True if the units are unitless. Unitless includes units that have
-    no units and units that are defined as '1'.
+    Returns True if the units for the associated standard name are
+    dimensionless.  Dimensionless standard names include those that have no
+    units and units that are defined as constant units in the CF standard name
+    table i.e. '1', or '1e-3'.
     '''
-    found_standard_name = xml_tree.find(".//entry[@id='{}']".format(units))
+    # standard_name must be string, so if it is not, it is *wrong* by default
+    if not isinstance(standard_name, basestring):
+        return False
+    found_standard_name = xml_tree.find(".//entry[@id='{}']".format(standard_name))
     if found_standard_name is not None:
         canonical_units = found_standard_name.find('canonical_units')
-        return canonical_units is None or canonical_units.text == '1'
+        # so far, standard name XML table includes
+        # 1 and 1e-3 for constant units, but expanding to valid udunits
+        # prefixes to be on the safe side
+        # taken from CF Table 3.1 of valid UDUnits prefixes
+        dimless_units = r'1(?:e-?(?:1|2|3|6|9|12|15|18|21|24))?$'
+        return canonical_units is None or re.match(dimless_units,
+                                                   canonical_units.text)
     # if the standard name is not found, assume we need units for the time being
     else:
         return False
@@ -95,9 +160,7 @@ def is_unitless(ds, variable):
     :param str variable: Name of the variable
     '''
     units = getattr(ds.variables[variable], 'units', None)
-    if units is None or units == '':
-        return True
-    return False
+    return units is None or units == ''
 
 
 def is_geophysical(ds, variable):
@@ -116,11 +179,23 @@ def is_geophysical(ds, variable):
     if getattr(ncvar, 'axis', None):
         return False
 
-    standard_name = getattr(ncvar, 'standard_name', '')
+    standard_name_test = getattr(ncvar, 'standard_name', '')
     unitless = is_unitless(ds, variable)
 
+    if not isinstance(standard_name_test, basestring):
+        warnings.warn("Variable {} has non string standard name, "
+                      "Attempting cast to string".format(variable))
+        try:
+            standard_name = str(standard_name_test)
+        except ValueError:
+            warnings.warn("Unable to cast standard name to string, excluding "
+                          "from geophysical variables")
+    else:
+        standard_name = standard_name_test
+
     # Is the standard name associated with coordinates
-    if standard_name in ('time', 'latitude', 'longitude', 'height', 'depth', 'altitude'):
+    if standard_name in {'time', 'latitude', 'longitude',
+                         'height', 'depth', 'altitude'}:
         return False
 
     if variable in get_coordinate_variables(ds):
@@ -233,7 +308,7 @@ def get_auxiliary_coordinate_variables(ds):
 
 def get_cell_boundary_map(ds):
     '''
-    Returns a dictionary mapping a variable to it's boundary variable. The
+    Returns a dictionary mapping a variable to its boundary variable. The
     returned dictionary maps a string variable name to the name of the boundary
     variable.
 
@@ -260,7 +335,7 @@ def get_cell_boundary_variables(ds):
             boundary_variables.append(var.bounds)
     return boundary_variables
 
-
+@lru_cache(128)
 def get_geophysical_variables(ds):
     '''
     Returns a list of variable names for the variables detected as geophysical
@@ -276,6 +351,7 @@ def get_geophysical_variables(ds):
     return parameters
 
 
+@lru_cache(128)
 def get_z_variable(nc):
     '''
     Returns the name of the variable that defines the Z axis or height/depth
@@ -345,6 +421,7 @@ def get_z_variables(nc):
     return z_variables
 
 
+@lru_cache(128)
 def get_lat_variable(nc):
     '''
     Returns the first variable matching latitude
@@ -373,7 +450,9 @@ def get_latitude_variables(nc):
         if variable.name not in latitude_variables:
             latitude_variables.append(variable.name)
 
-    for variable in nc.get_variables_by_attributes(units=lambda x: x is not None and x.lower() in VALID_LAT_UNITS):
+    check_fn = partial(attr_membership, value_set=VALID_LAT_UNITS,
+                           modifier_fn=lambda s: s.lower())
+    for variable in nc.get_variables_by_attributes(units=check_fn):
         if variable.name not in latitude_variables:
             latitude_variables.append(variable.name)
 
@@ -406,6 +485,7 @@ def get_true_latitude_variables(nc):
     return true_lats
 
 
+@lru_cache(128)
 def get_lon_variable(nc):
     '''
     Returns the variable for longitude
@@ -434,7 +514,9 @@ def get_longitude_variables(nc):
         if variable.name not in longitude_variables:
             longitude_variables.append(variable.name)
 
-    for variable in nc.get_variables_by_attributes(units=lambda x: x is not None and x.lower() in VALID_LON_UNITS):
+    check_fn = partial(attr_membership, value_set=VALID_LON_UNITS,
+                       modifier_fn=lambda s: s.lower())
+    for variable in nc.get_variables_by_attributes(units=check_fn):
         if variable.name not in longitude_variables:
             longitude_variables.append(variable.name)
 
@@ -537,24 +619,25 @@ def get_time_variable(ds):
     return None
 
 
+@lru_cache(128)
 def get_time_variables(ds):
     '''
     Returns a list of variables describing the time coordinate
 
     :param netCDF4.Dataset ds: An open netCDF4 Dataset
     '''
-    time_variables = []
+    time_variables = set()
     for variable in ds.get_variables_by_attributes(standard_name='time'):
-        time_variables.append(variable.name)
+        time_variables.add(variable.name)
 
     for variable in ds.get_variables_by_attributes(axis='T'):
         if variable.name not in time_variables:
-            time_variables.append(variable.name)
+            time_variables.add(variable.name)
 
     regx = r'^(?:day|d|hour|hr|h|minute|min|second|s)s? since .*$'
     for variable in ds.get_variables_by_attributes(units=lambda x: isinstance(x, basestring)):
         if re.match(regx, variable.units) and variable.name not in time_variables:
-            time_variables.append(variable.name)
+            time_variables.add(variable.name)
 
     return time_variables
 
@@ -624,6 +707,7 @@ def get_grid_mapping_variables(ds):
     return grid_mapping_variables
 
 
+@lru_cache(128)
 def get_axis_map(ds, variable):
     '''
     Returns an axis_map dictionary that contains an axis key and the coordinate
@@ -655,7 +739,6 @@ def get_axis_map(ds, variable):
     # {'x': ['longitude'], 'y': ['latitude'], 't': ['time']}
     axis_map = defaultdict(list)
     for coord_name in all_coords:
-
         if is_compression_coordinate(ds, coord_name):
             axis = 'C'
         elif coord_name in times:
@@ -676,21 +759,6 @@ def get_axis_map(ds, variable):
         elif coord_name in coordinates:
             if coord_name not in axis_map[axis]:
                 axis_map[axis].append(coord_name)
-
-    # Sometimes dimensionless coordinates are considered coordinate variables.
-    # I know, it's confusing.
-    if 'X' not in axis_map and longitudes:
-        axis_map['X'] = longitudes
-
-    if 'Y' not in axis_map and latitudes:
-        axis_map['Y'] = latitudes
-
-    if 'T' not in axis_map and times:
-        axis_map['T'] = times
-
-    if 'Z' not in axis_map and heights:
-        axis_map['Z'] = heights
-
     return axis_map
 
 
